import request from '@/utils/request'

// 查询医生文章列表
export function listArticle(query) {
  return request({
    url: '/his/doctorArticle/list',
    method: 'get',
    params: query
  })
}

// 查询医生名称列表
export function listdocuser(query) {
  return request({
    url: '/his/doctor/userdoc/list',
    method: 'get',
    params: query
  })
}


export function listDocList(query) {
  return request({
    url: '/his/doctor/doc/list',
    method: 'get',
    params: query
  })
}

// 查询医生文章详细
export function getArticle(articleId) {
  return request({
    url: '/his/doctorArticle/' + articleId,
    method: 'get'
  })
}

// 新增医生文章
export function addArticle(data) {
  return request({
    url: '/his/doctorArticle',
    method: 'post',
    data: data
  })
}

// 修改医生文章
export function updateArticle(data) {
  return request({
    url: '/his/doctorArticle',
    method: 'put',
    data: data
  })
}

// 删除医生文章
export function delArticle(articleId) {
  return request({
    url: '/his/doctorArticle/' + articleId,
    method: 'delete'
  })
}

// 导出医生文章
export function exportArticle(query) {
  return request({
    url: '/his/doctorArticle/export',
    method: 'get',
    params: query
  })
}
